Welcome to PyNMR-STAR!
======================================

A Python module for reading, writing, and manipulating NMR-STAR files.

|BuildStatus| |License| |Wheel| |PythonVersions|

Python versions supported: 3.6, 3.7, 3.8, and 3.9.

Overview
--------

This library was developed by the BMRB to give the Python-using NMR
community tools to work with the NMR-STAR data format. It is used
internally and is actively maintained. The library is thoroughly
documented such that calling ``help(object_or_method)`` from an
interactive python session will print the documentation for the object
or method. An even more convenient way to learn how to use this library
is to read the documentation at `read the docs <https://pynmrstar.readthedocs.org>`__.

.. |BuildStatus| image:: https://travis-ci.org/uwbmrb/PyNMRSTAR.svg?branch=v3
   :target: https://travis-ci.org/uwbmrb/PyNMRSTAR

.. |PythonVersions| image:: https://img.shields.io/pypi/pyversions/pynmrstar.svg
   :target: https://pypi.org/project/PyNMRSTAR

.. |License| image:: https://img.shields.io/pypi/l/pynmrstar.svg
   :target: https://pypi.org/project/PyNMRSTAR

.. |Wheel| image:: https://img.shields.io/pypi/wheel/pynmrstar.svg
   :target: https://pypi.org/project/PyNMRSTAR
